@@ -208,7 +208,7 @@ class AliddnsCore:
                 return False
 
         self.update_dns_record(ddns_record, self._rc_record_id, self._Aliyun_API_Type)
-        if ddns_record_v6 is None:
+        if ddns_record_v6:
             self.update_dns_record(ddns_record_v6, self._rc_record_v6_id, 
                 self._Aliyun_API_V6_Type, True)
 
